@@ -2,7 +2,7 @@ package Net::SolarWinds::REST::Batch;
 
 =head1 NAME
 
-Net::SolarWinds::REST::Batch - SolarWinds Batch Prcess class
+Net::SolarWinds::REST::Batch - SolarWinds Batch Process class
 
 =head1 SYNOPSIS
 
@@ -108,6 +108,7 @@ Example of the data of $struct:
       "Allow64BitCounters" => true
    },
 
+   # Note: This requires the APM module in Solarwinds
    # denote objects used to create templates
    # see also: add_templates
    "templates" => [
@@ -416,16 +417,8 @@ Returns a Net::SolarWinds::Result object, when true it contains a hash mapping i
 
 sub getPollerInterfaceMap {
   my ($self,$nodeid)=@_;
-  my $query=qq{select
-    p.PollerType,
-    i.interfacetype as ifType,
-    count(i.interfaceid) as totalinterfaces
-    FROM 
-    Orion.NPM.Interfaces as i
-    inner join Orion.Pollers as p on i.InterfaceID=p.NetObjectID and p.NetObjectType='I'
-    where 
-    i.NodeID=$nodeid
-    group by p.PollerType,i.interfacetype};
+  my $query=$self->query_lookup($nodeid);
+
   my $result=$self->Query($query);
   return $result unless $result;
 
@@ -435,9 +428,9 @@ sub getPollerInterfaceMap {
   foreach my $poller (@{$list}) {
     my $id=$poller->{ifType};
     $hash->{$id}=[] unless exists $hash->{$id};
-
     push @{$hash->{$id}},$poller->{PollerType};
   }
+
   return $self->RESULT_CLASS->new_true($hash);
 }
 
@@ -449,20 +442,7 @@ When true it returns a Net::SolarWinds::Result object that contains the interfac
 
 sub GetNodeInterfacePollers {
   my ($self,$nodeid)=@_;
-  my $query=qq{select
-    p.PollerType,
-    i.interfacetype as ifType,
-    i.InterfaceName as ifName,
-    i.InterfaceID,
-    i.Uri as InterfaceUri,
-    p.Uri as PollerUri
-    FROM 
-    Orion.NPM.Interfaces as i
-    left join Orion.Pollers as p on i.InterfaceID=p.NetObjectID and p.NetObjectType='I'
-    where 
-    i.NodeID=$nodeid
-    order by i.InterfaceID
-    };
+  my $query=$self->query_lookup($nodeid);
   my $result=$self->Query($query);
   return $result;
 }
